--[[ $Id: AceWardrobe_UI.lua 8141 2006-08-16 05:50:05Z badhex $ ]]--

local dewdrop = DewdropLib:GetInstance('1.0')

AceWardrobe_UI = AceAddon:new({
	name          = "AceWardrobe UI",
	description   = "UI plugin for AceWardrobe",
	version       = "3.2.1",
	aceCompatible = 103,
	author        = "Kazun of Warsong",
	category      = "interface",
	hasIcon       = TRUE,
	db		= AceDatabase:new("AceWardrobeUIDB"),
	cmd		= AceChatCmd:new(WARDROBEUI.COMMANDS, WARDROBEUI.CMD_OPTIONS),

	-- Methods

	Enable = function(self)
		self:Hook(AceWardrobe, "SaveOutfit", "MySaveOutfit")
		self:Hook(AceWardrobe, "WearOutfit", "MyWearOutfit")
	end,

	Disable = function(self)
		self:Unhook(AceWardrobe, "SaveOutfit")
		self:Unhook(AceWardrobe, "WearOutfit")
	end,

	Initialize = function (self)
		if (self.db:get("HideIcon") == TRUE) then
			AceWardrobe_UI_Button:Hide();
		else
			AceWardrobe_UI_Button:Show();
		end
	end,

	LoadButton = function(self)
		if dewdrop:IsOpen(AceWardrobe_UI_Button) then
			dewdrop:Close()
			return
		end
		if not dewdrop:IsRegistered(AceWardrobe_UI_Button) then
			dewdrop:Register(AceWardrobe_UI_Button,
			'point', "TOPRIGHT",
			'relativePoint', "BOTTOMLEFT",
			'children', function(level, value, valueN_1, valueN_2, valueN_3, valueN_4)
					self:MenuSettings(level, value, true, valueN_1, valueN_2, valueN_3, valueN_4)
				end)
		end
	end,

	MenuOnEnter = function(self)
		if (self.db:get("MenuOnEnter")) then
			dewdrop:Open(AceWardrobe_UI_Button)
		end
	end,

	TogMenuOnEnter = function(self)
		self.db:toggle("MenuOnEnter")
		if (self.db:get("MenuOnEnter") == FALSE) then
			self.cmd:msg(WARDROBEUI.MenuOnEnter_DISABLE)
		else
			self.cmd:msg(WARDROBEUI.MenuOnEnter_ENABLE)
		end	
	end,

	ToggleLockUI = function(self)
		-- lock or unlock the UI button
		self.db:toggle("Locked")
		if (self.db:get("Locked") == FALSE) then
			-- not locked
			self.cmd:msg(WARDROBEUI.BUTTON_UNLOCK)
		else
			-- locked
			self.cmd:msg(WARDROBEUI.BUTTON_LOCK)
		end
	end,

	ToggleHideIcon = function (self)
		self.db:toggle("HideIcon")
		if (self.db:get("HideIcon") == FALSE) then
			-- not hide
			self.cmd:msg(WARDROBEUI.BUTTON_UNHIDE)
			AceWardrobe_UI_Button:Show();
		else
			-- hide
			self.cmd:msg(WARDROBEUI.BUTTON_HIDE)
			AceWardrobe_UI_Button:Hide();
		end
	end,

	OnDragStart = function(self)
		if (self.db:get("Locked") == FALSE) then
			AceWardrobe_UI_Button:StartMoving()
			WARDROBEUI.BeingDragged = true
		end
	end,

	OnDragStop = function(self)
		-- Save the button location
		if (self.db:get("Locked") == FALSE) then
			if (WARDROBEUI.BeingDragged) then
				AceWardrobe_UI_Button:StopMovingOrSizing()
				WARDROBEUI.BeingDragged = false
				local x,y = this:GetCenter()
				local px,py = this:GetParent():GetCenter()
				local ox = x-px
				local oy = y-py
				self.db:set("xOffset", ox)
				self.db:set("yOffset", oy)
			end
		end
	end,

	ResetIconPos = function()
		AceWardrobe_UI_Button:ClearAllPoints();
		AceWardrobe_UI_Button:SetPoint("CENTER", "Minimap", "CENTER", -37, -74);
		AceWardrobe_UI.db:set("xOffset", -37)
		AceWardrobe_UI.db:set("yOffset", -74)
		AceWardrobe_UI.cmd:msg(WARDROBEUI.IconRested)
	end,

	MenuSettings = function(self,level,value)
		local outfitList = AceWardrobe:OutfitList()
		
		if (outfitList ~= nil) then
			if level == 1 then

				dewdrop:AddLine(
				    'text', WARDROBEUI.Outfits,
				    'isTitle', true
				)
				dewdrop:AddLine()

				for i = 1, table.getn(outfitList) do
					if(outfitList[i] ~= "") then
						dewdrop:AddLine(
							'text', string.format("%s", outfitList[i]),
							'func', function(j) AceWardrobe:WearOutfit(j) end,
							'arg1',i,
							'checked', (i == AceWardrobe:CurrentOutfit())
						)
					end
				end

				dewdrop:AddLine()

				dewdrop:AddLine(
					'text', WARDROBEUI.SaveNew,
					'func', function() self:NewSave() end
				)

				dewdrop:AddLine(
					'text', WARDROBEUI.SlotsUsed,
					'hasArrow', true,
					'value', "slots"
				)

				dewdrop:AddLine(
					'text', WARDROBEUI.Update,
					'hasArrow', true,
					'value', "update"
				)

				dewdrop:AddLine(
					'text', WARDROBEUI.Delete,
					'hasArrow', true,
					'value', "delete"
				)
				dewdrop:AddLine(
					'text', WARDROBEUI.SetDefault,
					'hasArrow', true,
					'value', "SetDefault"
				)
				dewdrop:AddLine(
					'text', WARDROBEUI.SetMount,
					'hasArrow', true,
					'value', "SetMount"
				)

				dewdrop:AddLine()
				
				dewdrop:AddLine(
					'text', WARDROBEUI.ClearMenu,
					'hasArrow', true,
					'value', "ClearMenu"
				)
				
				dewdrop:AddLine(
					'text', WARDROBEUI.GeneralSettings,
					'hasArrow', true,
					'value', "GeneralSettings"
				)

				dewdrop:AddLine(
					'text', WARDROBEUI.IconSettings,
					'hasArrow', true,
					'value', "IconSettings"
				)

			elseif level == 2 then
				if value == "update" then
					for i = 1, table.getn(outfitList) do
						if(outfitList[i] ~= "") then
							dewdrop:AddLine(
								'text', string.format("%s", outfitList[i]),
								'func', function(j) AceWardrobe:UpdateOutfit(j) end,
								'arg1', i
							)
						end
					end
				
				elseif value == "delete" then
					for i = 1, table.getn(outfitList) do
						if(outfitList[i] ~= "") then
							dewdrop:AddLine(
								'text', string.format("%s", outfitList[i]),
								'func', function(j) AceWardrobe:DeleteOutfit(j) dewdrop:Refresh(1) end,
								'arg1', i
							)
						end
					end
				
				elseif value == "slots" then
					for i = 1, table.getn(outfitList) do
						if(outfitList[i] ~= "") then
							dewdrop:AddLine(
								'text', string.format("%s", outfitList[i]),
								'hasArrow', true,
								'value', i
							)
						end
					end

				elseif value == "SetDefault" then
					for i = 1, table.getn(outfitList) do
						if(outfitList[i] ~= "") then
							dewdrop:AddLine(
								'text', string.format("%s", outfitList[i]),
								'func', function(j) AceWardrobe:SetDefaultOutfit(j) end,
								'arg1', i,
								'checked', (i == AceWardrobe.GetOpt({ }, "Default"))
							)
						end
					end
				
				elseif value == "SetMount" then
					for i = 1, table.getn(outfitList) do
						if(outfitList[i] ~= "") then
							dewdrop:AddLine(
								'text', string.format("%s", outfitList[i]),
								'func', function(j) AceWardrobe:SetMountedOutfit(j) end,
								'arg1', i,
								'checked', (i == AceWardrobe.GetOpt({ }, "Mounted"))
							)
						end
					end
				
				elseif value == "ClearMenu" then
					dewdrop:AddLine(
						'text', WARDROBEUI.ClearForms,
						'func', function() AceWardrobe:ClearForms() end
					)
					dewdrop:AddLine(
						'text', WARDROBEUI.ClearDefault,
						'func', function() AceWardrobe:SetDefaultOutfit("") end
					)
					dewdrop:AddLine(
						'text', WARDROBEUI.ClearMounted,
						'func', function() AceWardrobe:SetMountedOutfit("") end
					)
					dewdrop:AddLine()
					dewdrop:AddLine(
						'text', WARDROBEUI.ClearAll,
						'func', function() self:ClearAllConfirm() end
					)

				elseif value == "GeneralSettings" then
					dewdrop:AddLine(
						'text', WARDROBEUI.SilentMode,
						'func', function() AceWardrobe:ToggleSilentMode() end,
						'checked',(TRUE == AceWardrobe.GetOpt({ }, "Silent"))
					)
					dewdrop:AddLine(
						'text', WARDROBEUI.LastUnmount,
						'func', function() AceWardrobe:ToggleLastUnmount() end,
						'checked',(TRUE == AceWardrobe.GetOpt({ }, "LastUnmount"))
					)
					dewdrop:AddLine(
						'text', WARDROBEUI.NoAuto,
						'func', function() AceWardrobe:TogNoAutoDefault() end,
						'checked',(TRUE == AceWardrobe.GetOpt({ }, "NoAuto"))
					)

				elseif value == "IconSettings" then
					dewdrop:AddLine(
						'text', WARDROBEUI.LockButton,
						'func', function() self:ToggleLockUI() end,
						'checked',(TRUE == self.db:get("Locked"))
					)
					dewdrop:AddLine(
						'text', WARDROBEUI.RestPosition,
						'func', function() self:ResetIconPos() end
					)
					dewdrop:AddLine(
						'text', WARDROBEUI.MenuOnEnter,
						'func', function() self:TogMenuOnEnter() end,
						'checked',(TRUE == self.db:get("MenuOnEnter"))
					)
				end
			elseif level == 3 then
				if value > 0 then
					local outfitItems = AceWardrobe:GetSavedOutfit(value)
					local newText = ""
					for i = 1, 20 do
						if(outfitItems[i] == "") then
							newText = ""
						else
							newText = outfitItems[i]
						end
						dewdrop:AddLine(
							'text', string.format("%s", newText),
							'checked', (0 == AceWardrobe:ReturnCheckedStatus(value, i)),
							'func', function(a, b) AceWardrobe:SetOutfitIgnoreSlot(string.format("%i %i",a, b)) end,
							'arg1', i,
							'arg2', value
						)
					end
				end
			end
		end
	end,

	MyWearOutfit = function(self,name)
		self:CallHook(AceWardrobe,"WearOutfit",name)
		dewdrop:Refresh(1)
	end,

	MySetOutfitIgnoreSlot = function(self,text)
		self:CallHook(AceWardrobe,"SetOutfitIgnoreSlot",text)
		dewdrop:Refresh(3)
	end,

	MySaveOutfit = function(self,name)
		self:CallHook(AceWardrobe,"SaveOutfit",name)
		dewdrop:Refresh(1)
	end,

	NewSave = function(self)
		StaticPopupDialogs["ACEWARDROBE_SAVE"] = {
			text = WARDROBEUI.EnterName,
			button1 = TEXT(ACCEPT),
			button2 = TEXT(CANCEL),
			hasEditBox = 1,
			maxLetters = 32,
			OnAccept = function()
				local text = getglobal(this:GetParent():GetName().."EditBox"):GetText()
				AceWardrobe:SaveOutfit(text)
			end,
			EditBoxOnEnterPressed = function()
				local text = getglobal(this:GetParent():GetName().."EditBox"):GetText()
				AceWardrobe:SaveOutfit(text)
			end,
			OnShow = function()
				getglobal(this:GetName().."EditBox"):SetFocus()
			end,
			OnHide = function()
				if ( ChatFrameEditBox:IsVisible() ) then
					ChatFrameEditBox:SetFocus()
				end
				getglobal(this:GetName().."EditBox"):SetText("")
			end,
			timeout = 0,
			exclusive = 1,
			hideOnEscape = 1
		}
		StaticPopup_Show ("ACEWARDROBE_SAVE")
		dewdrop:Refresh(1)
	end,

	ClearAllConfirm = function(self)
		StaticPopupDialogs["ACEWARDROBE_CLEARALLCONFIRM"] = {
			text = WARDROBEUI.ClearAllConfirm,
			button1 = TEXT(ACCEPT),
			button2 = TEXT(CANCEL),
			OnAccept = function()
				AceWardrobe:ClearAllOutfits()
				dewdrop:Refresh(1)
			end,
			timeout = 0,
			exclusive = 1,
			hideOnEscape = 1
		}
		StaticPopup_Show ("ACEWARDROBE_CLEARALLCONFIRM")
	end
})

WARDROBEUI.BeingDragged = false

AceWardrobe_UI:RegisterForLoad()